/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import { useBlockProps, InspectorControls, BlockControls } from '@wordpress/block-editor';
import { Panel, PanelBody, PanelRow, TextControl, Button } from '@wordpress/components';

import { MediaToolbar, Image } from '@10up/block-components';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit(props) {
	const { attributes, setAttributes } = props;
	const { heading, backgroundImage, buttonText, buttonLink } = attributes;

	const handleBackgroundImageSelect = (image) => {
		setAttributes({
			backgroundImage: image.id,
		});
	};

	const handleBackgroundImageRemove = () => {
		setAttributes({
			backgroundImage: null,
		});
	};


	return (
		<div { ...useBlockProps() }>
			

			<div class="call-to-action">
				<h2>{heading}</h2>
				<a href={buttonLink} class="btn btn-primary btn-lg">{buttonText}</a>
			</div>

			<InspectorControls>
				<Panel>
					<PanelBody title={ __( 'Background Image Settings', 'featured-image-block' ) }>
						<PanelRow>
							<Image
								id={backgroundImage}
								className="my-image"
								size="full"
								onSelect={handleBackgroundImageSelect}
								labels={{
									title: 'Select Background Image',
									instructions: 'Upload a media file or pick one from your media library.'
								}}
							/>
						</PanelRow>
						<PanelRow>
							<Button isDestructive variant="link" onClick={handleBackgroundImageRemove}>Remove Background Image</Button>
						</PanelRow>
						<PanelRow>
							<TextControl
								__nextHasNoMarginBottom
								__next40pxDefaultSize
								label={ __(
									'Heading',
									'featured-image-block'
								) }
								value={ heading || '' }
								onChange={ ( value ) =>
									setAttributes( { heading: value } )
								}
							/>
						</PanelRow>
						<PanelRow>
							<TextControl
								__nextHasNoMarginBottom
								__next40pxDefaultSize
								label={ __(
									'Button Link',
									'featured-image-block'
								) }
								value={ buttonLink || '' }
								onChange={ ( value ) =>
									setAttributes( { buttonLink: value } )
								}
							/>
						</PanelRow>
						<PanelRow>
							<TextControl
								__nextHasNoMarginBottom
								__next40pxDefaultSize
								label={ __(
									'Button Text',
									'featured-image-block'
								) }
								value={ buttonText || '' }
								onChange={ ( value ) =>
									setAttributes( { buttonText: value } )
								}
							/>
						</PanelRow>
					</PanelBody>
				</Panel>
			</InspectorControls>


            <BlockControls>
                <MediaToolbar
                    isOptional
                    id={ backgroundImage }
                    onSelect={ handleBackgroundImageSelect }
                    onRemove={ handleBackgroundImageRemove }
                />
            </BlockControls>
			
			
			<Image
				id={backgroundImage}
				className="my-image"
				size="full"
				onSelect={handleBackgroundImageSelect}
				labels={{
					title: 'Select Background Image',
					instructions: 'Upload a media file or pick one from your media library.'
				}}
			/>
		</div>
	);
}
